@@ -7,6 +7,7 @@ import (
 	"fmt"
 
 	"github.com/cpu/goacmedns"
+	"github.com/go-acme/lego/v4/challenge"
 	"github.com/go-acme/lego/v4/challenge/dns01"
 	"github.com/go-acme/lego/v4/platform/config/env"
 )
@@ -23,6 +24,8 @@ const (
 	EnvStoragePath = envNamespace + "STORAGE_PATH"
 )
 
+var _ challenge.Provider = (*DNSProvider)(nil)
+
 // acmeDNSClient is an interface describing the goacmedns.Client functions the DNSProvider uses.
 // It makes it easier for tests to shim a mock Client into the DNSProvider.
 type acmeDNSClient interface {
