@@ -12,9 +12,12 @@ import (
 	"github.com/Azure/azure-sdk-for-go/sdk/azcore/cloud"
 	"github.com/Azure/azure-sdk-for-go/sdk/azcore/to"
 	"github.com/Azure/azure-sdk-for-go/sdk/resourcemanager/privatedns/armprivatedns"
+	"github.com/go-acme/lego/v4/challenge"
 	"github.com/go-acme/lego/v4/challenge/dns01"
 )
 
+var _ challenge.ProviderTimeout = (*DNSProviderPrivate)(nil)
+
 // DNSProviderPrivate implements the challenge.Provider interface for Azure Private Zone DNS.
 type DNSProviderPrivate struct {
 	config                *Config
