@@ -9,13 +9,12 @@ import (
 	"sync"
 	"time"
 
+	"github.com/go-acme/lego/v4/challenge"
 	"github.com/go-acme/lego/v4/challenge/dns01"
 	"github.com/go-acme/lego/v4/platform/config/env"
 	"github.com/go-acme/lego/v4/providers/dns/loopia/internal"
 )
 
-const minTTL = 300
-
 // Environment variables names.
 const (
 	envNamespace = "LOOPIA_"
@@ -30,6 +29,10 @@ const (
 	EnvHTTPTimeout        = envNamespace + "HTTP_TIMEOUT"
 )
 
+const minTTL = 300
+
+var _ challenge.ProviderTimeout = (*DNSProvider)(nil)
+
 type dnsClient interface {
 	AddTXTRecord(ctx context.Context, domain string, subdomain string, ttl int, value string) error
 	RemoveTXTRecord(ctx context.Context, domain string, subdomain string, recordID int) error
