@@ -6,13 +6,12 @@ import (
 	"crypto/x509"
 	"encoding/base64"
 	"encoding/pem"
-	"io/ioutil"
 	"os"
 	"testing"
 	"time"
 
 	"github.com/go-acme/lego/v4/platform/tester"
-	"github.com/oracle/oci-go-sdk/common"
+	"github.com/oracle/oci-go-sdk/v65/common"
 	"github.com/stretchr/testify/require"
 )
 
@@ -307,7 +306,7 @@ func mustGeneratePrivateKeyFile(pwd string) string {
 		panic(err)
 	}
 
-	file, err := ioutil.TempFile("", "lego_oci_*.pem")
+	file, err := os.CreateTemp("", "lego_oci_*.pem")
 	if err != nil {
 		panic(err)
 	}
